Module allocator

Module allocator 

Allocators moddule.

Structs

ContiguousMemoryLayoutPolicy
Allocators where every allocations is with contiguous memory.
Pitch
The 2D geometry of a copy to or from a pitched allocation: how wide each row is, how many rows there are, and the stride between their starts.
PitchedMemoryLayoutPolicy
Allocators where some allocations can leverage a pitched layout.

Functions

offset_handles
Take a list of sub-slices of a buffer and create a list of offset handles. Sizes must be in bytes and handles will be aligned to the memory alignment.