Module logging

Module logging 

Logging utilities to be used by a compute server.

Structs

Duration
A Duration type to represent a span of time, typically used for system timeouts.
LaunchObservation
Watches every launch the process issues for as long as it lives, then puts back whatever it replaced.
ProfileDuration
Result from profiling between two measurements. This can either be a duration or a future that resolves to a duration.
ProfileTicks
Start and end point for a profile. Can be turned into a duration.
ServerLogger
Server logger.

Enums

ProfileLevel
Control the amount of info being display when profiling.
TimingMethod
How a benchmark’s execution times are measured.
TimingRequest
What an observer asks be done with each launch’s measurement.

Traits

LaunchObserver
Notified of every kernel launch, on the thread that issued it.