Compute Storage module.
Storage implementations. The [ComputeStorage] contract is
cubecl-runtime’s and re-exported here.
Structs
- Bytes
Resource - This struct is a pointer to a memory chunk or slice.
- Bytes
Storage - The bytes storage maps ids to pointers of bytes in a contiguous layout.
- Managed
Resource - Access to the underlying resource.
- Pinned
Memory Alloc Controller - Hands out a pinned allocation as
Bytes, keeping the allocation alive for as long as the bytes are. - Pinned
Memory Resource - A range of page-locked host memory.
- Storage
Handle - Contains the storage id of a resource and the way it is used.
- Storage
Id - Storage ID.
- Storage
Utilization - Defines if data uses a full memory chunk or a slice of it.
Constants
- PINNED_
MEMORY_ ALIGNMENT - The alignment pinned allocations are handed out at.
Traits
- Compute
Storage - Storage types are responsible for allocating and deallocating memory.