MultiStream

Struct MultiStream 

pub struct MultiStream<B: EventStreamBackend> {
    pub logger: Arc<ServerLogger>,
    /* private fields */
}
Manages multiple streams with synchronization logic based on shared bindings.

This struct handles the creation and alignment of streams to ensure proper synchronization when bindings (e.g., buffers) are shared across different streams.

Fields

logger: Arc<ServerLogger>

The logger used by the server.

Implementations

Source

impl<B: EventStreamBackend> MultiStream<B>

pub fn backend_mut(&mut self) -> &mut B

Mutable access to the stream-creation backend, e.g. to change the configuration new streams are created with. Already-created streams are unaffected.

pub fn new(logger: Arc<ServerLogger>, backend: B, max_streams: u8) -> Self

Creates an empty multi-stream.

pub fn stream_ids(&self) -> impl Iterator<Item = StreamId> + '_

Synthetic StreamIds, one per initialized stream (see StreamPool::stream_ids).

pub fn gc(&mut self, gc: GcTask<B>)

Enqueue a task to be cleaned.

pub fn try_stream_mut(&mut self, stream_id: &StreamId) -> Option<&mut B::Stream>

The backend stream on stream_id’s slot when that slot was ever initialized, mutably — a lookup that must not create a stream (see StreamPool::try_get_mut).

pub fn resolve<'a>( &mut self, stream_id: StreamId, handles: impl Iterator<Item = &'a BufferBinding>, ) -> ResolvedStreams<'_, B>

Resolves and returns a mutable reference to the stream for the given ID, performing any necessary alignment based on the provided bindings.

This method ensures that the stream is synchronized with any shared bindings from other streams before returning the stream reference.