tune_benchmark

Function tune_benchmark 

pub fn tune_benchmark<'a, F, Out>(
    operation: &TuneFn<F, Out>,
    inputs: <F as TuneInputs>::At<'a>,
    client: Client,
    evictor: Option<&mut (dyn FnMut() -> Result<(), AutotuneError> + Send)>,
) -> Result<Vec<ProfileDuration>, AutotuneError>
where F: TuneInputs, Out: AutotuneOutput,
Benchmark how long this operation takes for a number of samples.

Returns at least one duration, otherwise an error is returned.