pub struct PersistentCacheKey<K> {
pub key: K,
pub checksum: String,
}Expand description
Persistent cache key
Fields
key: KThe autotune key identifying the operation.
checksum: StringThe checksum of the candidate list the key was tuned under: an answer to another list is an answer to another question.