pub fn tune_benchmark<'a, F, Out>(
operation: &TuneFn<F, Out>,
inputs: <F as TuneInputs>::At<'a>,
client: Client,
evictor: Option<&mut (dyn FnMut() -> Result<(), AutotuneError> + Send)>,
) -> Result<Vec<ProfileDuration>, AutotuneError>where
F: TuneInputs,
Out: AutotuneOutput,Expand description
Benchmark how long this operation takes for a number of samples.
Returns at least one duration, otherwise an error is returned.